@@ -2,12 +2,14 @@ from flask import *  # noqa: Expose all flask objects as top level imports
 from flask import request
 from slack import WebClient as Slack
 
-from .flack import Slackify
+from .main import Slackify
+from .blueprint import Blueprint
 from .slack import ACK, OK, block_reply, reply_text, reply, respond, text_block
 from .tasks import async_task
 
 __all__ = [
     'Slackify',
+    'Blueprint',
     'Slack',
     'request',
     'reply_text',
